@@ -9,6 +9,7 @@ def create_tables():
     User.create_table()
     Role.create_table()
     Project.create_table()
+    ProjectBranch.create_table()
     ProjectRole.create_table()
     Commit.create_table()
     CommitFile.create_table()
@@ -60,6 +61,14 @@ class Project(DBModel):
         self._git_control = util.GitProject(self)
         return self._git_control
 
+class ProjectBranch(DBModel):
+
+    name = CharField()
+    project = ForeignKeyField(Project, related_name='branches')
+
+    class Meta:
+        primary_key = CompositeKey('name', 'project')
+
 class Role(DBModel):
     
     NAMES = (
